@@ -9,6 +9,12 @@ def register_fausans_font():
     This function tries to register the FAU Sans font by scanning the common font directories.
     If the font is not found, it will throw an error.
 
+    After successful registration, the font can be used in matplotlib by setting the following rcParams:
+    >>> import matplotlib.pyplot as plt
+    >>> plt.rcParams['font.family'] = 'sans-serif'
+    >>> plt.rcParams['font.sans-serif'] = 'FAUSans Office'
+
+
     Raises
     ------
     FileNotFoundError
@@ -23,6 +29,7 @@ def register_fausans_font():
     for path in possible_paths:
         if path.exists():
             font_manager.fontManager.addfont(path)
+            print("Successfully registered FAU Sans font.")
             return
 
     raise FileNotFoundError(
